.. _install_req:

Requirements
============

HydraTK is implemented in Python. Before you can install, you must fulfill basic requirements.

* Any OS Linux - distributions Debian, Red Hat, Fedora, SuSe, Slackware, Gentoo, Arch, FreeBSD with default package manager
* Python interpreter - versions CPython 2.6, 2.7, 3.3, 3.4, 3.5, 3.6, PyPy 2.7
* Python modules - setuptools, pip, wheel (actual versions)

.. note::

   OS Windows and MacOS are not supported, but there are future plans to support them.